"use client";

import DataTable from "@/components/tables/DataTable";
import { DeleteIcon } from "@chakra-ui/icons";
import { Button, Flex, Icon, useColorModeValue, useToast } from "@chakra-ui/react";
import { columnsDataBlocks } from "../variables/columnsBlock";
import { TableData } from "@/variables/columnsData";
import { deleteClubOwner } from "@/app/lib/club-owner/action";
import { useRouter } from "next/navigation";
import { PlayerInterface } from "../type/player";



export default function PlayerTable({ data, role }: { data: PlayerInterface[], role: any }) {
  const brandColor = useColorModeValue("brand.500", "white");
  const result = data.length > 0 ? data : [];

  // TODO: Bug - Feature club delete player will delete from whole application instead of club

  const toast = useToast();
  const router = useRouter();

  const deleteUser = async (id: number) => {
    const res = await deleteClubOwner(data[id]._id);
    if (res.status == 200) {
      toast({
        title: "200",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      router.refresh();
    } else {
      toast({
        title: res.status,
        description: res.error,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  const action = (id: number) => (
    <Flex gap={2}>
      <Button
        variant="blank"
        alignItems="center"
        justifyContent="center"
        w="37px"
        h="37px"
        lineHeight="100%"
        borderRadius="10px"
        onClick={() => {
          deleteUser(id);
        }}>
        <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
      </Button>
    </Flex>
  );

  return (
    <>
      <DataTable columnsData={columnsDataBlocks} tableData={result as unknown as TableData[]} isSelectable={false} showPageSize={false} actionSlot={action} />
    </>
  );
}
